@@ -97,6 +97,10 @@ class FileRepository:
                     f.write(file.content)
             saved = True
 
+    def remove_all(self, files: set[models.File]):
+        for file in files:
+            file.path.unlink(missing_ok=True)
+
 
 class DocumentFileRepository:
     def __init__(self, dir_path: Path, recursive=False, lang=None, use_ocr=None):
@@ -124,10 +128,18 @@ class DocumentFileRepository:
         elif not file.binary:
             doc = models.Document(file.path.stem, str(file.path), file.content)
         else:
-            log.warning(f'Ignoring unsupported file "{file.path.name}", as it cannot be read.')
+            log.error(f'The file "{file.path.name}" has an unsupported encoding and cannot be read.')
             doc = None
         return doc
 
+    def save_all(self, docs: set[models.Document]):
+        files = {models.File(Path(doc.path), doc.text, False) for doc in docs}
+        self._file_repo.save_all(files)
+
+    def remove_all(self, docs: set[models.Document]):
+        files = {models.File(Path(doc.path), doc.text, False) for doc in docs}
+        self._file_repo.remove_all(files)
+
 
 class DocumentPairRepository:
     def __init__(self, doc1: models.Document, doc2: models.Document):
@@ -195,18 +207,14 @@ class PdfReader:
 
     def __init__(self, file, lang, use_ocr):
         self._file = file
-        self._lang = lang if lang == 'eng' else 'deu'
+        self._lang = 'eng' if lang == 'en' else 'deu'
         self._use_ocr = use_ocr
 
     def extract_urls(self) -> set[str]:
-        # Temporary fix for: https://github.com/jsvine/pdfplumber/issues/463
-        try:
-            with pdfplumber.open(self._file) as pdf:
-                parsed_urls = {urlparse(uri_obj['uri'], "https") for uri_obj in pdf.hyperlinks}
-                return {parsed_url.geturl().rstrip('/').replace("///", "//")
-                        for parsed_url in filter(lambda url: url.scheme in ("http", "https"), parsed_urls)}
-        except UnicodeDecodeError:
-            log.warning(f'Could not extract hyperlinks from PDF "{self._file.name}".')
+        with pdfplumber.open(self._file) as pdf:
+            parsed_urls = {urlparse(uri_obj['uri'], "https") for uri_obj in pdf.hyperlinks}
+            return {parsed_url.geturl().rstrip('/').replace("///", "//")
+                    for parsed_url in filter(lambda url: url.scheme in ("http", "https"), parsed_urls)}
 
     def extract_text(self):
         text = self._extract()
